configuration

package
v0.0.0-...-37f0e8b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: Apache-2.0 Imports: 12 Imported by: 5

Documentation

Index

Constants

This section is empty.

Variables

DefaultAuthorizerFactory constructs deduplicated authorizers based on options specified in configuration messages.

Functions

This section is empty.

Types

type AuthorizerFactory

type AuthorizerFactory interface {
	// NewAuthorizerFromConfiguration constructs an authorizer based on
	// options specified in a configuration message.
	NewAuthorizerFromConfiguration(configuration *pb.AuthorizerConfiguration, group program.Group, grpcClientFactory grpc.ClientFactory) (auth.Authorizer, error)
}

AuthorizerFactory can be used to construct authorizers based on options specified in a configuration message.

func NewDeduplicatingAuthorizerFactory

func NewDeduplicatingAuthorizerFactory(base AuthorizerFactory) AuthorizerFactory

NewDeduplicatingAuthorizerFactory creates a new AuthorizerFactory which returns the same Authorizer for identical configurations, which may allow for things like sharing caches.

type BaseAuthorizerFactory

type BaseAuthorizerFactory struct{}

BaseAuthorizerFactory can be used to construct authorizers based on options specified in a configuration message.

func (BaseAuthorizerFactory) NewAuthorizerFromConfiguration

func (BaseAuthorizerFactory) NewAuthorizerFromConfiguration(config *pb.AuthorizerConfiguration, group program.Group, grpcClientFactory grpc.ClientFactory) (auth.Authorizer, error)

NewAuthorizerFromConfiguration constructs an authorizer based on options specified in a configuration message.

Jump to